# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The display commands module.

These commands are used in the following models:
SS3706A

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - display.clear()
    - display.getannunciators()
    - display.getcursor()
    - display.getlastkey()
    - display.gettext()
    - display.inputvalue()
    - display.loadmenu.add()
    - display.loadmenu.delete()
    - display.locallockout
    - display.menu()
    - display.prompt()
    - display.screen
    - display.sendkey()
    - display.setcursor()
    - display.settext()
    - display.waitkey()
"""
from typing import Optional, TYPE_CHECKING, Union

from .._helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


# pylint: disable=too-few-public-methods
class DisplayTrigger(BaseTSPCmd):
    """The ``display.trigger`` command tree.

    Constants:
        - ``.EVENT_ID``: The event ID of the event generated when the front-panel TRIG key is
          pressed.
    """

    EVENT_ID = "display.trigger.EVENT_ID"
    """str: The event ID of the event generated when the front-panel TRIG key is pressed."""


class DisplayLoadmenu(BaseTSPCmd):
    """The ``display.loadmenu`` command tree.

    Properties/methods:
        - ``.add()``: The ``display.loadmenu.add()`` function.
        - ``.delete()``: The ``display.loadmenu.delete()`` function.
    """

    def add(self, display_name: str, code: str, memory: Optional[str] = None) -> None:
        """Run the ``display.loadmenu.add()`` function.

        **Description:**
            - This function adds an entry to the USER TESTS menu, which can be accessed by pressing
              the LOAD key on the front panel.

        **TSP Syntax:**

        ::

            - display.loadmenu.add()

        Args:
            display_name: The name that is added to the USER TESTS menu.
            code: The code that is run from the USER TESTS menu.
            memory (optional): Determines if code is saved to nonvolatile memory.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    f'"{display_name}"',
                    f'"{code}"',
                    memory,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.add({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.add()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def delete(self, display_name: str) -> None:
        """Run the ``display.loadmenu.delete()`` function.

        **Description:**
            - This function removes an entry from the USER TESTS menu, which can be accessed using
              the LOAD key on the front panel.

        **TSP Syntax:**

        ::

            - display.loadmenu.delete()

        Args:
            display_name: The name to be deleted from the USER TESTS menu.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f'{self._cmd_syntax}.delete("{display_name}")'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.delete()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class Display(BaseTSPCmd):
    """The ``display`` command tree.

    Properties/methods:
        - ``.clear()``: The ``display.clear()`` function.
        - ``.getannunciators()``: The ``display.getannunciators()`` function.
        - ``.getcursor()``: The ``display.getcursor()`` function.
        - ``.getlastkey()``: The ``display.getlastkey()`` function.
        - ``.gettext()``: The ``display.gettext()`` function.
        - ``.inputvalue()``: The ``display.inputvalue()`` function.
        - ``.loadmenu``: The ``display.loadmenu`` command tree.
        - ``.locallockout``: The ``display.locallockout`` attribute.
        - ``.menu()``: The ``display.menu()`` function.
        - ``.prompt()``: The ``display.prompt()`` function.
        - ``.screen``: The ``display.screen`` attribute.
        - ``.sendkey()``: The ``display.sendkey()`` function.
        - ``.setcursor()``: The ``display.setcursor()`` function.
        - ``.settext()``: The ``display.settext()`` function.
        - ``.trigger``: The ``display.trigger`` command tree.
        - ``.waitkey()``: The ``display.waitkey()`` function.
    """

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "display") -> None:
        super().__init__(device, cmd_syntax)
        self._loadmenu = DisplayLoadmenu(device, f"{self._cmd_syntax}.loadmenu")
        self._trigger = DisplayTrigger(device, f"{self._cmd_syntax}.trigger")

    @property
    def loadmenu(self) -> DisplayLoadmenu:
        """Return the ``display.loadmenu`` command tree.

        Sub-properties/methods:
            - ``.add()``: The ``display.loadmenu.add()`` function.
            - ``.delete()``: The ``display.loadmenu.delete()`` function.
        """
        return self._loadmenu

    @property
    def locallockout(self) -> str:
        """Access the ``display.locallockout`` attribute.

        **Description:**
            - This attribute describes whether or not the EXIT (LOCAL) key on the instrument
              virtualfront panel is enabled.

        **Usage:**
            - Accessing this property will send the ``print(display.locallockout)`` query.
            - Setting this property to a value will send the ``display.locallockout = value``
              command.

        **TSP Syntax:**

        ::

            - display.locallockout = value
            - print(display.locallockout)

        **Info:**
            - ``lockout``, the 0 or display.UNLOCK: Unlocks EXIT (LOCAL) key
              1 or display.LOCK: Locks out EXIT (LOCAL) key.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".locallockout"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.locallockout)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.locallockout`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @locallockout.setter
    def locallockout(self, value: Union[str, float]) -> None:
        """Access the ``display.locallockout`` attribute.

        **Description:**
            - This attribute describes whether or not the EXIT (LOCAL) key on the instrument
              virtualfront panel is enabled.

        **Usage:**
            - Accessing this property will send the ``print(display.locallockout)`` query.
            - Setting this property to a value will send the ``display.locallockout = value``
              command.

        **TSP Syntax:**

        ::

            - display.locallockout = value
            - print(display.locallockout)

        **Info:**
            - ``lockout``, the 0 or display.UNLOCK: Unlocks EXIT (LOCAL) key
              1 or display.LOCK: Locks out EXIT (LOCAL) key.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".locallockout", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.locallockout = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.locallockout`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def screen(self) -> str:
        """Access the ``display.screen`` attribute.

        **Description:**
            - This attribute contains the selected display screen.

        **Usage:**
            - Accessing this property will send the ``print(display.screen)`` query.
            - Setting this property to a value will send the ``display.screen = value`` command.

        **TSP Syntax:**

        ::

            - display.screen = value
            - print(display.screen)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".screen"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.screen)"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.screen`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @screen.setter
    def screen(self, value: Union[str, float]) -> None:
        """Access the ``display.screen`` attribute.

        **Description:**
            - This attribute contains the selected display screen.

        **Usage:**
            - Accessing this property will send the ``print(display.screen)`` query.
            - Setting this property to a value will send the ``display.screen = value`` command.

        **TSP Syntax:**

        ::

            - display.screen = value
            - print(display.screen)

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".screen", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.screen = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to access the ``{self._cmd_syntax}.screen`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def trigger(self) -> DisplayTrigger:
        """Return the ``display.trigger`` command tree.

        Constants:
            - ``.EVENT_ID``: The event ID of the event generated when the front-panel TRIG key is
              pressed.
        """
        return self._trigger

    def clear(self) -> None:
        """Run the ``display.clear()`` function.

        **Description:**
            - This function clears the text from the front-panel USER swipe screen.

        **TSP Syntax:**

        ::

            - display.clear()

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f"{self._cmd_syntax}.clear()")  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getannunciators(self) -> str:
        """Run the ``display.getannunciators()`` function.

        **Description:**
            - This function reads the annunciators (indicators) that are presently turned on.

        **TSP Syntax:**

        ::

            - display.getannunciators()

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getannunciators())"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.getannunciators()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getcursor(self) -> str:
        """Run the ``display.getcursor()`` function.

        **Description:**
            - This function reads the present position of the cursor on the virtualfront-panel
              display.

        **TSP Syntax:**

        ::

            - display.getcursor()

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getcursor())"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.getcursor()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getlastkey(self) -> str:
        """Run the ``display.getlastkey()`` function.

        **Description:**
            - This function retrieves the key code for the last pressed key.

        **TSP Syntax:**

        ::

            - display.getlastkey()

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getlastkey())"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.getlastkey()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def gettext(
        self,
        embellished: Optional[str] = None,
        row: Optional[str] = None,
        column_start: Optional[str] = None,
        column_end: Optional[int] = None,
    ) -> str:
        """Run the ``display.gettext()`` function.

        **Description:**
            - This function reads the text displayed on the virtualfront panel.

        **TSP Syntax:**

        ::

            - display.gettext()

        Args:
            embellished (optional): Indicates type of returned text.
            row (optional): Selects the row from which to read the text.
            column_start (optional): Selects the first column from which to read text; for row 1,
                the valid column numbers are 1 to 20; for row 2, the valid column numbers are 1 to
                32; if nothing is selected, 1 is used.
            column_end (optional): Selects the last column from which to read text; for row 1, the
                valid column numbers are 1 to 20; for row 2, the valid column numbers are 1 to 32;
                the default is 20 for row 1, and 32 for row 2.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    embellished,
                    row,
                    column_start,
                    column_end,
                )
                if x is not None
            )
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.gettext({function_args}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.gettext()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def inputvalue(
        self,
        format_: str,
        default: Optional[str] = None,
        minimum: Optional[str] = None,
        maximum: Optional[str] = None,
    ) -> str:
        """Run the ``display.inputvalue()`` function.

        **Description:**
            - This function displays a formatted input field on the virtualfront-panel display that
              the operator can edit.

        **TSP Syntax:**

        ::

            - display.inputvalue()

        Args:
            format_: A string that defines how the input field is formatted; see Details for more
                information.
            default (optional): The default value for the input value.
            minimum (optional): The minimum input value.
            maximum (optional): The maximum input value.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    f'"{format_}"',
                    default,
                    minimum,
                    maximum,
                )
                if x is not None
            )
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.inputvalue({function_args}))"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.inputvalue()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def menu(self, name: str, items: str) -> str:
        """Run the ``display.menu()`` function.

        **Description:**
            - This function presents a menu on the virtualfront-panel display.

        **TSP Syntax:**

        ::

            - display.menu()

        Args:
            name: Menu name to display on the top line.
            items: Menu items to display on the bottom line.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.menu("{name}", "{items}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.menu()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def prompt(self, button_id: str, prompt_text: str) -> str:
        """Run the ``display.prompt()`` function.

        **Description:**
            - This function allows you to create an interactive dialog prompt that displays a custom
              message on the front-panel display.

        **TSP Syntax:**

        ::

            - display.prompt()

        Args:
            button_id: The type of prompt to display; choose one of the following options.
            prompt_text: A string that contains the text that is displayed above the prompts.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.prompt({button_id}, "{prompt_text}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.prompt()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def sendkey(self, key_code: str) -> None:
        """Run the ``display.sendkey()`` function.

        **Description:**
            - This function sends a code that simulates the action of a front-panel control.

        **TSP Syntax:**

        ::

            - display.sendkey()

        Args:
            key_code: A parameter that specifies the key press to simulate; see Details for more
                information.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.sendkey({key_code})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.sendkey()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def setcursor(self, row: str, column: str, style: Optional[str] = None) -> None:
        """Run the ``display.setcursor()`` function.

        **Description:**
            - This function sets the position of the cursor.

        **TSP Syntax:**

        ::

            - display.setcursor()

        Args:
            row: The row number for the cursor (1 or 2).
            column: The active column position to set; row 1 has columns 1 to 20, row 2 has columns
                1 to 32.
            style (optional): Set the cursor to invisible (0, default) or blinking (1).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    row,
                    column,
                    style,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.setcursor({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.setcursor()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def settext(
        self, user_display_text1: Optional[str] = None, user_display_text2: Optional[str] = None
    ) -> None:
        """Run the ``display.settext()`` function.

        **Description:**
            - This function defines the text that is displayed on the front-panel USER swipe screen.

        **TSP Syntax:**

        ::

            - display.settext()

        Args:
            user_display_text1 (optional): String that contains the message for the top line of the
                USER swipe screen (up to 20 characters).
            user_display_text2 (optional): String that contains the message for the bottom line of
                the USER swipe screen (up to 32 characters).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    f'"{user_display_text1}"' if user_display_text1 is not None else None,
                    f'"{user_display_text2}"' if user_display_text2 is not None else None,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.settext({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.settext()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def waitkey(self) -> str:
        """Run the ``display.waitkey()`` function.

        **Description:**
            - This function captures the key code value for the next front-panel action.

        **TSP Syntax:**

        ::

            - display.waitkey()

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.waitkey())"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.waitkey()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



"""A module with all the main device type classes."""
from typing import Final

from tm_devices.drivers.api.rest_api.margin_testers.margin_tester import MarginTester
from tm_devices.drivers.pi.data_acquisition_systems.data_acquisition_system import (
    DataAcquisitionSystem,
)
from tm_devices.drivers.pi.digital_multimeters.digital_multimeter import DigitalMultimeter
from tm_devices.drivers.pi.power_supplies.power_supply import PowerSupplyUnit
from tm_devices.drivers.pi.scopes.scope import Scope
from tm_devices.drivers.pi.signal_sources.afgs.afg import AFG
from tm_devices.drivers.pi.signal_sources.awgs.awg import AWG
from tm_devices.drivers.pi.source_measure_units.source_measure_unit import SourceMeasureUnit
from tm_devices.drivers.pi.systems_switches.systems_switch import SystemsSwitch

DEVICE_TYPE_CLASSES: Final = (
    AFG,
    AWG,
    DataAcquisitionSystem,
    DigitalMultimeter,
    PowerSupplyUnit,
    SourceMeasureUnit,
    Scope,
    SystemsSwitch,
    MarginTester,
)

__all__ = [
    "DEVICE_TYPE_CLASSES",
    "AFG",
    "AWG",
    "DataAcquisitionSystem",
    "DigitalMultimeter",
    "PowerSupplyUnit",
    "SourceMeasureUnit",
    "Scope",
    "SystemsSwitch",
    "MarginTester",
]



"""The customtable commands module.

These commands are used in the following models:
LPD6, MSO4, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - CUSTOMTABle:ADDNew <Qstring>
    - CUSTOMTABle:DELete <Qstring>
    - CUSTOMTABle:LIST? <Qstring>
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdReadWithArguments, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class CustomtableList(SCPICmdReadWithArguments):
    """The ``CUSTOMTABle:LIST`` command.

    **Description:**
        - This command queries the list of custom result tables has been added.

    **Usage:**
        - Using the ``.query(argument)`` method will send the ``CUSTOMTABle:LIST? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the ``CUSTOMTABle:LIST? argument``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - CUSTOMTABle:LIST? <Qstring>

    **Info:**
        - ``<Qstring>`` specifies the custom results table name.
    """


class CustomtableDelete(SCPICmdWrite):
    """The ``CUSTOMTABle:DELete`` command.

    **Description:**
        - This command deletes the custom result(s) table that was added.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``CUSTOMTABle:DELete value`` command.

    **SCPI Syntax:**

    ::

        - CUSTOMTABle:DELete <Qstring>

    **Info:**
        - ``<Qstring>`` specifies the custom results table name.
    """


class CustomtableAddnew(SCPICmdWrite):
    """The ``CUSTOMTABle:ADDNew`` command.

    **Description:**
        - This command adds new custom results table.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``CUSTOMTABle:ADDNew value`` command.

    **SCPI Syntax:**

    ::

        - CUSTOMTABle:ADDNew <Qstring>

    **Info:**
        - ``<Qstring>`` specifies the custom results table name.
    """


class Customtable(SCPICmdRead):
    """The ``CUSTOMTABle`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``CUSTOMTABle?`` query.
        - Using the ``.verify(value)`` method will send the ``CUSTOMTABle?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.addnew``: The ``CUSTOMTABle:ADDNew`` command.
        - ``.delete``: The ``CUSTOMTABle:DELete`` command.
        - ``.list``: The ``CUSTOMTABle:LIST`` command.
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "CUSTOMTABle"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._addnew = CustomtableAddnew(device, f"{self._cmd_syntax}:ADDNew")
        self._delete = CustomtableDelete(device, f"{self._cmd_syntax}:DELete")
        self._list = CustomtableList(device, f"{self._cmd_syntax}:LIST")

    @property
    def addnew(self) -> CustomtableAddnew:
        """Return the ``CUSTOMTABle:ADDNew`` command.

        **Description:**
            - This command adds new custom results table.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``CUSTOMTABle:ADDNew value`` command.

        **SCPI Syntax:**

        ::

            - CUSTOMTABle:ADDNew <Qstring>

        **Info:**
            - ``<Qstring>`` specifies the custom results table name.
        """
        return self._addnew

    @property
    def delete(self) -> CustomtableDelete:
        """Return the ``CUSTOMTABle:DELete`` command.

        **Description:**
            - This command deletes the custom result(s) table that was added.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``CUSTOMTABle:DELete value`` command.

        **SCPI Syntax:**

        ::

            - CUSTOMTABle:DELete <Qstring>

        **Info:**
            - ``<Qstring>`` specifies the custom results table name.
        """
        return self._delete

    @property
    def list(self) -> CustomtableList:
        """Return the ``CUSTOMTABle:LIST`` command.

        **Description:**
            - This command queries the list of custom result tables has been added.

        **Usage:**
            - Using the ``.query(argument)`` method will send the ``CUSTOMTABle:LIST? argument``
              query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CUSTOMTABle:LIST? argument`` query and raise an AssertionError if the returned value
              does not match ``value``.

        **SCPI Syntax:**

        ::

            - CUSTOMTABle:LIST? <Qstring>

        **Info:**
            - ``<Qstring>`` specifies the custom results table name.
        """
        return self._list



"""The totaluptime commands module.

These commands are used in the following models:
DPO2K, DPO2KB, DPO4K, DPO4KB, LPD6, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO2, MSO2K, MSO2KB, MSO4,
MSO4K, MSO4KB, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - TOTaluptime?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class Totaluptime(SCPICmdRead):
    """The ``TOTaluptime`` command.

    **Description:**
        - Total number of hours the instrument has been turned on since the NV memory was last
          programmed, usually during the initial manufacturing process.

    **Usage:**
        - Using the ``.query()`` method will send the ``TOTaluptime?`` query.
        - Using the ``.verify(value)`` method will send the ``TOTaluptime?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - TOTaluptime?
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "TOTaluptime"
    ) -> None:
        super().__init__(device, cmd_syntax)



"""The plot commands module.

These commands are used in the following models:
MSO2

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - PLOT:ADDNew <QString>
    - PLOT:DELete <QString>
    - PLOT:LIST?
    - PLOT:PLOT<x>:SOUrce1 MEAS<x>
    - PLOT:PLOT<x>:SOUrce1?
    - PLOT:PLOT<x>:TYPe {NONE|XY}
"""
from typing import Dict, Optional, TYPE_CHECKING

from .._helpers import (
    DefaultDictPassKeyToFactory,
    SCPICmdRead,
    SCPICmdWrite,
    ValidatedDynamicNumberCmd,
)

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class PlotPlotItemType(SCPICmdWrite):
    """The ``PLOT:PLOT<x>:TYPe`` command.

    **Description:**
        - This command sets or returns the current plot type of the specified plot.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``PLOT:PLOT<x>:TYPe value`` command.

    **SCPI Syntax:**

    ::

        - PLOT:PLOT<x>:TYPe {NONE|XY}

    **Info:**
        - ``<x>`` is the plot number. This is the equivalent of the number shown on a plot heading
          in the UI.
        - ``NONE`` does not create a plot.
        - ``XY`` creates a XY plot.
    """


class PlotPlotItemSource1(SCPICmdWrite, SCPICmdRead):
    """The ``PLOT:PLOT<x>:SOUrce1`` command.

    **Description:**
        - This command sets or queries the plot source.

    **Usage:**
        - Using the ``.query()`` method will send the ``PLOT:PLOT<x>:SOUrce1?`` query.
        - Using the ``.verify(value)`` method will send the ``PLOT:PLOT<x>:SOUrce1?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``PLOT:PLOT<x>:SOUrce1 value`` command.

    **SCPI Syntax:**

    ::

        - PLOT:PLOT<x>:SOUrce1 MEAS<x>
        - PLOT:PLOT<x>:SOUrce1?

    **Info:**
        - ``MEAS<x>`` is the specified measurement source for the specified plot.
    """


class PlotPlotItem(ValidatedDynamicNumberCmd, SCPICmdRead):
    """The ``PLOT:PLOT<x>`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``PLOT:PLOT<x>?`` query.
        - Using the ``.verify(value)`` method will send the ``PLOT:PLOT<x>?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.source1``: The ``PLOT:PLOT<x>:SOUrce1`` command.
        - ``.type``: The ``PLOT:PLOT<x>:TYPe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._source1 = PlotPlotItemSource1(device, f"{self._cmd_syntax}:SOUrce1")
        self._type = PlotPlotItemType(device, f"{self._cmd_syntax}:TYPe")

    @property
    def source1(self) -> PlotPlotItemSource1:
        """Return the ``PLOT:PLOT<x>:SOUrce1`` command.

        **Description:**
            - This command sets or queries the plot source.

        **Usage:**
            - Using the ``.query()`` method will send the ``PLOT:PLOT<x>:SOUrce1?`` query.
            - Using the ``.verify(value)`` method will send the ``PLOT:PLOT<x>:SOUrce1?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``PLOT:PLOT<x>:SOUrce1 value``
              command.

        **SCPI Syntax:**

        ::

            - PLOT:PLOT<x>:SOUrce1 MEAS<x>
            - PLOT:PLOT<x>:SOUrce1?

        **Info:**
            - ``MEAS<x>`` is the specified measurement source for the specified plot.
        """
        return self._source1

    @property
    def type(self) -> PlotPlotItemType:
        """Return the ``PLOT:PLOT<x>:TYPe`` command.

        **Description:**
            - This command sets or returns the current plot type of the specified plot.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``PLOT:PLOT<x>:TYPe value`` command.

        **SCPI Syntax:**

        ::

            - PLOT:PLOT<x>:TYPe {NONE|XY}

        **Info:**
            - ``<x>`` is the plot number. This is the equivalent of the number shown on a plot
              heading in the UI.
            - ``NONE`` does not create a plot.
            - ``XY`` creates a XY plot.
        """
        return self._type


class PlotList(SCPICmdRead):
    """The ``PLOT:LIST`` command.

    **Description:**
        - This command lists all currently defined plots.

    **Usage:**
        - Using the ``.query()`` method will send the ``PLOT:LIST?`` query.
        - Using the ``.verify(value)`` method will send the ``PLOT:LIST?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - PLOT:LIST?
    """


class PlotDelete(SCPICmdWrite):
    """The ``PLOT:DELete`` command.

    **Description:**
        - This command deletes the specified plot.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``PLOT:DELete value`` command.

    **SCPI Syntax:**

    ::

        - PLOT:DELete <QString>

    **Info:**
        - ``<QString>`` is the specified plot. Argument is of the form 'PLOT<NR1>, where <NR1> is ≥
          1).
    """

    _WRAP_ARG_WITH_QUOTES = True


class PlotAddnew(SCPICmdWrite):
    """The ``PLOT:ADDNew`` command.

    **Description:**
        - This command adds the specified plot.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``PLOT:ADDNew value`` command.

    **SCPI Syntax:**

    ::

        - PLOT:ADDNew <QString>

    **Info:**
        - ``<QString>`` is the specified plot. The argument is of the form 'PLOT<NR1>', where <NR1>
          ≥ 1.
    """

    _WRAP_ARG_WITH_QUOTES = True


class Plot(SCPICmdRead):
    """The ``PLOT`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``PLOT?`` query.
        - Using the ``.verify(value)`` method will send the ``PLOT?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.addnew``: The ``PLOT:ADDNew`` command.
        - ``.delete``: The ``PLOT:DELete`` command.
        - ``.list``: The ``PLOT:LIST`` command.
        - ``.plot``: The ``PLOT:PLOT<x>`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "PLOT") -> None:
        super().__init__(device, cmd_syntax)
        self._addnew = PlotAddnew(device, f"{self._cmd_syntax}:ADDNew")
        self._delete = PlotDelete(device, f"{self._cmd_syntax}:DELete")
        self._list = PlotList(device, f"{self._cmd_syntax}:LIST")
        self._plot: Dict[int, PlotPlotItem] = DefaultDictPassKeyToFactory(
            lambda x: PlotPlotItem(device, f"{self._cmd_syntax}:PLOT{x}")
        )

    @property
    def addnew(self) -> PlotAddnew:
        """Return the ``PLOT:ADDNew`` command.

        **Description:**
            - This command adds the specified plot.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``PLOT:ADDNew value`` command.

        **SCPI Syntax:**

        ::

            - PLOT:ADDNew <QString>

        **Info:**
            - ``<QString>`` is the specified plot. The argument is of the form 'PLOT<NR1>', where
              <NR1> ≥ 1.
        """
        return self._addnew

    @property
    def delete(self) -> PlotDelete:
        """Return the ``PLOT:DELete`` command.

        **Description:**
            - This command deletes the specified plot.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``PLOT:DELete value`` command.

        **SCPI Syntax:**

        ::

            - PLOT:DELete <QString>

        **Info:**
            - ``<QString>`` is the specified plot. Argument is of the form 'PLOT<NR1>, where <NR1>
              is ≥ 1).
        """
        return self._delete

    @property
    def list(self) -> PlotList:
        """Return the ``PLOT:LIST`` command.

        **Description:**
            - This command lists all currently defined plots.

        **Usage:**
            - Using the ``.query()`` method will send the ``PLOT:LIST?`` query.
            - Using the ``.verify(value)`` method will send the ``PLOT:LIST?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - PLOT:LIST?
        """
        return self._list

    @property
    def plot(self) -> Dict[int, PlotPlotItem]:
        """Return the ``PLOT:PLOT<x>`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``PLOT:PLOT<x>?`` query.
            - Using the ``.verify(value)`` method will send the ``PLOT:PLOT<x>?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.source1``: The ``PLOT:PLOT<x>:SOUrce1`` command.
            - ``.type``: The ``PLOT:PLOT<x>:TYPe`` command.
        """
        return self._plot



# ruff: noqa: D402,PLR0913
# pyright: reportConstantRedefinition=none
"""The fs commands module.

These commands are used in the following models:
DAQ6510, DMM6500, DMM7510, SMU2450, SMU2460, SMU2461, SMU2470, SMU2601B, SMU2602B, SMU2604B,
SMU2606B, SMU2611B, SMU2612B, SMU2614B, SMU2634B, SMU2635B, SMU2636B, SMU2651A, SMU2657A, SS3706A

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:

::

    - fs.chdir()
    - fs.cwd()
    - fs.is_dir()
    - fs.is_file()
    - fs.mkdir()
    - fs.readdir()
    - fs.rmdir()
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.drivers.pi.tsp_device import TSPDevice


class Fs(BaseTSPCmd):
    """The ``fs`` command tree.

    Properties/methods:
        - ``.chdir()``: The ``fs.chdir()`` function.
        - ``.cwd()``: The ``fs.cwd()`` function.
        - ``.is_dir()``: The ``fs.is_dir()`` function.
        - ``.is_file()``: The ``fs.is_file()`` function.
        - ``.mkdir()``: The ``fs.mkdir()`` function.
        - ``.readdir()``: The ``fs.readdir()`` function.
        - ``.rmdir()``: The ``fs.rmdir()`` function.
    """

    def __init__(self, device: Optional["TSPDevice"] = None, cmd_syntax: str = "fs") -> None:
        super().__init__(device, cmd_syntax)

    def chdir(self, path: str) -> str:
        """Run the ``fs.chdir()`` function.

        **Description:**
            - This function sets the current working directory.

        **TSP Syntax:**

        ::

            - fs.chdir()

        Args:
            path: A string indicating the new working directory path.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.chdir("{path}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.chdir()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def cwd(self) -> str:
        """Run the ``fs.cwd()`` function.

        **Description:**
            - This function returns the absolute path of the current working directory.

        **TSP Syntax:**

        ::

            - fs.cwd()

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.cwd())"
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.cwd()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def is_dir(self, path: str) -> str:
        """Run the ``fs.is_dir()`` function.

        **Description:**
            - This function tests whether or not the specified path refers to a directory.

        **TSP Syntax:**

        ::

            - fs.is_dir()

        Args:
            path: The path of the file system entry to test.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.is_dir("{path}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.is_dir()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def is_file(self, path: str) -> str:
        """Run the ``fs.is_file()`` function.

        **Description:**
            - Tests whether the specified path refers to a file (as opposed to a directory).

        **TSP Syntax:**

        ::

            - fs.is_file()

        Args:
            path: The path of the file system entry to test.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.is_file("{path}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.is_file()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def mkdir(self, new_path: str) -> str:
        """Run the ``fs.mkdir()`` function.

        **Description:**
            - This function creates a directory at the specified path.

        **TSP Syntax:**

        ::

            - fs.mkdir()

        Args:
            new_path: Location (path) of where to create the new directory.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.mkdir("{new_path}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.mkdir()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def readdir(self, path: str) -> str:
        """Run the ``fs.readdir()`` function.

        **Description:**
            - This function returns a list of the file system entries in the directory.

        **TSP Syntax:**

        ::

            - fs.readdir()

        Args:
            path: The directory path.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.readdir("{path}"))'
            )
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.readdir()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def rmdir(self, path: str) -> None:
        """Run the ``fs.rmdir()`` function.

        **Description:**
            - This function removes a directory from the file system.

        **TSP Syntax:**

        ::

            - fs.rmdir()

        Args:
            path: The path of the directory to remove.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(f'{self._cmd_syntax}.rmdir("{path}")')  # type: ignore[union-attr]
        except AttributeError as error:
            msg = f"No TSPDevice object was provided, unable to run the ``{self._cmd_syntax}.rmdir()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



"""The idnmultiscope commands module.

These commands are used in the following models:
DPO70KSX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - IDNMultiscope:A?
    - IDNMultiscope:B?
    - IDNMultiscope:C?
    - IDNMultiscope:D?
    - IDNMultiscope?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class IdnmultiscopeDigitalBit(SCPICmdRead):
    """The ``IDNMultiscope:D`` command.

    **Description:**
        - This query returns the ``*IDN?`` response for Extension 3. If the query is not run on the
          master instrument, data returned indicates that the instrument is running as a StandAlone
          Master. DPO70000SX Series only.

    **Usage:**
        - Using the ``.query()`` method will send the ``IDNMultiscope:D?`` query.
        - Using the ``.verify(value)`` method will send the ``IDNMultiscope:D?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - IDNMultiscope:D?
    """


class IdnmultiscopeC(SCPICmdRead):
    """The ``IDNMultiscope:C`` command.

    **Description:**
        - This query returns the ``*IDN?`` response for Extension 2. If the query is not run on the
          master instrument, data returned indicates that the instrument is running as a StandAlone
          Master. DPO70000SX Series only.

    **Usage:**
        - Using the ``.query()`` method will send the ``IDNMultiscope:C?`` query.
        - Using the ``.verify(value)`` method will send the ``IDNMultiscope:C?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - IDNMultiscope:C?
    """


class IdnmultiscopeB(SCPICmdRead):
    """The ``IDNMultiscope:B`` command.

    **Description:**
        - This query returns the ``*IDN?`` response for Extension 1. If the query is not run on the
          master instrument, data returned indicates that the instrument is running as a StandAlone
          Master. DPO70000SX Series only.

    **Usage:**
        - Using the ``.query()`` method will send the ``IDNMultiscope:B?`` query.
        - Using the ``.verify(value)`` method will send the ``IDNMultiscope:B?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - IDNMultiscope:B?
    """


class IdnmultiscopeA(SCPICmdRead):
    """The ``IDNMultiscope:A`` command.

    **Description:**
        - This query returns the ``*IDN?`` response for the Master instrument. If the query is not
          run on the master instrument, data returned indicates that the instrument is running as a
          StandAlone Master. DPO70000SX Series only.

    **Usage:**
        - Using the ``.query()`` method will send the ``IDNMultiscope:A?`` query.
        - Using the ``.verify(value)`` method will send the ``IDNMultiscope:A?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - IDNMultiscope:A?
    """


class Idnmultiscope(SCPICmdRead):
    """The ``IDNMultiscope`` command.

    **Description:**
        - This query returns instrument data on all MultiScope instruments. If the query is not run
          on the master instrument, data returned indicates that the instrument is running as a
          StandAlone Master. DPO70000SX Series only.

    **Usage:**
        - Using the ``.query()`` method will send the ``IDNMultiscope?`` query.
        - Using the ``.verify(value)`` method will send the ``IDNMultiscope?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - IDNMultiscope?

    Properties:
        - ``.a``: The ``IDNMultiscope:A`` command.
        - ``.b``: The ``IDNMultiscope:B`` command.
        - ``.c``: The ``IDNMultiscope:C`` command.
        - ``.d``: The ``IDNMultiscope:D`` command.
    """

    def __init__(
        self, device: Optional["PIDevice"] = None, cmd_syntax: str = "IDNMultiscope"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._a = IdnmultiscopeA(device, f"{self._cmd_syntax}:A")
        self._b = IdnmultiscopeB(device, f"{self._cmd_syntax}:B")
        self._c = IdnmultiscopeC(device, f"{self._cmd_syntax}:C")
        self._d = IdnmultiscopeDigitalBit(device, f"{self._cmd_syntax}:D")

    @property
    def a(self) -> IdnmultiscopeA:
        """Return the ``IDNMultiscope:A`` command.

        **Description:**
            - This query returns the ``*IDN?`` response for the Master instrument. If the query is
              not run on the master instrument, data returned indicates that the instrument is
              running as a StandAlone Master. DPO70000SX Series only.

        **Usage:**
            - Using the ``.query()`` method will send the ``IDNMultiscope:A?`` query.
            - Using the ``.verify(value)`` method will send the ``IDNMultiscope:A?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - IDNMultiscope:A?
        """
        return self._a

    @property
    def b(self) -> IdnmultiscopeB:
        """Return the ``IDNMultiscope:B`` command.

        **Description:**
            - This query returns the ``*IDN?`` response for Extension 1. If the query is not run on
              the master instrument, data returned indicates that the instrument is running as a
              StandAlone Master. DPO70000SX Series only.

        **Usage:**
            - Using the ``.query()`` method will send the ``IDNMultiscope:B?`` query.
            - Using the ``.verify(value)`` method will send the ``IDNMultiscope:B?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - IDNMultiscope:B?
        """
        return self._b

    @property
    def c(self) -> IdnmultiscopeC:
        """Return the ``IDNMultiscope:C`` command.

        **Description:**
            - This query returns the ``*IDN?`` response for Extension 2. If the query is not run on
              the master instrument, data returned indicates that the instrument is running as a
              StandAlone Master. DPO70000SX Series only.

        **Usage:**
            - Using the ``.query()`` method will send the ``IDNMultiscope:C?`` query.
            - Using the ``.verify(value)`` method will send the ``IDNMultiscope:C?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - IDNMultiscope:C?
        """
        return self._c

    @property
    def d(self) -> IdnmultiscopeDigitalBit:
        """Return the ``IDNMultiscope:D`` command.

        **Description:**
            - This query returns the ``*IDN?`` response for Extension 3. If the query is not run on
              the master instrument, data returned indicates that the instrument is running as a
              StandAlone Master. DPO70000SX Series only.

        **Usage:**
            - Using the ``.query()`` method will send the ``IDNMultiscope:D?`` query.
            - Using the ``.verify(value)`` method will send the ``IDNMultiscope:D?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - IDNMultiscope:D?
        """
        return self._d



"""MSO5LP device driver module."""
from tm_devices.commands import MSO5LPMixin
from tm_devices.drivers.pi.scopes.tekscope.mso5 import MSO5


class MSO5LP(MSO5LPMixin, MSO5):
    """MSO5LP device driver."""



"""The ethernet commands module.

These commands are used in the following models:
DPO2K, DPO2KB, MSO2K, MSO2KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - ETHERnet:DHCPbootp {ON|OFF}
    - ETHERnet:DHCPbootp?
    - ETHERnet:DNS:IPADDress <QString>
    - ETHERnet:DNS:IPADDress?
    - ETHERnet:DOMAINname <Qstring>
    - ETHERnet:DOMAINname?
    - ETHERnet:ENET:ADDress?
    - ETHERnet:GATEWay:IPADDress <QString>
    - ETHERnet:GATEWay:IPADDress?
    - ETHERnet:HTTPPort <QString>
    - ETHERnet:HTTPPort?
    - ETHERnet:IPADDress <QString>
    - ETHERnet:IPADDress?
    - ETHERnet:NAME <QString>
    - ETHERnet:NAME?
    - ETHERnet:PASSWord <new>
    - ETHERnet:PASSWord?
    - ETHERnet:PING EXECute
    - ETHERnet:PING:STATUS?
    - ETHERnet:SUBNETMask <QString>
    - ETHERnet:SUBNETMask?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class EthernetSubnetmask(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:SUBNETMask`` command.

    **Description:**
        - This command sets or queries the instrument subnet mask value.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:SUBNETMask?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:SUBNETMask?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:SUBNETMask value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:SUBNETMask <QString>
        - ETHERnet:SUBNETMask?

    **Info:**
        - ``<QString>`` is the subnet mask value, enclosed in quotes.
    """

    _WRAP_ARG_WITH_QUOTES = True


class EthernetPingStatus(SCPICmdRead):
    """The ``ETHERnet:PING:STATUS`` command.

    **Description:**
        - Returns the results from sending the ``ETHERNET:PING`` command to ping the gateway IP
          address.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:PING:STATUS?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:PING:STATUS?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ETHERnet:PING:STATUS?
    """


class EthernetPing(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:PING`` command.

    **Description:**
        - Sends a ping packet to the instrument gateway and sets the status accordingly.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``ETHERnet:PING value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:PING EXECute

    Properties:
        - ``.status``: The ``ETHERnet:PING:STATUS`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._status = EthernetPingStatus(device, f"{self._cmd_syntax}:STATUS")

    @property
    def status(self) -> EthernetPingStatus:
        """Return the ``ETHERnet:PING:STATUS`` command.

        **Description:**
            - Returns the results from sending the ``ETHERNET:PING`` command to ping the gateway IP
              address.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:PING:STATUS?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:PING:STATUS?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ETHERnet:PING:STATUS?
        """
        return self._status


class EthernetPassword(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:PASSWord`` command.

    **Description:**
        - This command specifies the HTTP Ethernet access password. If a password is set, the user
          must enter the password before the user's Web browser can access the oscilloscope.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:PASSWord?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:PASSWord?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:PASSWord value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:PASSWord <new>
        - ETHERnet:PASSWord?

    **Info:**
        - ``<new>`` is a new password, enclosed in quotes.
    """


class EthernetName(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:NAME`` command.

    **Description:**
        - This command sets or queries the instrument Ethernet hostname assigned to the instrument.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:NAME?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:NAME?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:NAME value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:NAME <QString>
        - ETHERnet:NAME?

    **Info:**
        - ``<QString>`` is the network name assigned to the instrument, enclosed in quotes.
    """

    _WRAP_ARG_WITH_QUOTES = True


class EthernetIpaddress(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:IPADDress`` command.

    **Description:**
        - This command sets the IP address assigned to the instrument.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:IPADDress?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:IPADDress?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:IPADDress value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:IPADDress <QString>
        - ETHERnet:IPADDress?

    **Info:**
        - ``<QString>`` is a standard IP address value, enclosed in quotes.
    """

    _WRAP_ARG_WITH_QUOTES = True


class EthernetHttpport(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:HTTPPort`` command.

    **Description:**
        - This command specifies the remote interface HTTP port value.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:HTTPPort?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:HTTPPort?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:HTTPPort value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:HTTPPort <QString>
        - ETHERnet:HTTPPort?

    **Info:**
        - ``<QString>`` is an integer port number, enclosed in quotes.
    """

    _WRAP_ARG_WITH_QUOTES = True


class EthernetGatewayIpaddress(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:GATEWay:IPADDress`` command.

    **Description:**
        - This command specifies the network gateway IP address.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:GATEWay:IPADDress?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:GATEWay:IPADDress?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:GATEWay:IPADDress value``
          command.

    **SCPI Syntax:**

    ::

        - ETHERnet:GATEWay:IPADDress <QString>
        - ETHERnet:GATEWay:IPADDress?

    **Info:**
        - ``<QString>`` is a standard IP address value, enclosed in quotes.
    """

    _WRAP_ARG_WITH_QUOTES = True


class EthernetGateway(SCPICmdRead):
    """The ``ETHERnet:GATEWay`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:GATEWay?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:GATEWay?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.ipaddress``: The ``ETHERnet:GATEWay:IPADDress`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._ipaddress = EthernetGatewayIpaddress(device, f"{self._cmd_syntax}:IPADDress")

    @property
    def ipaddress(self) -> EthernetGatewayIpaddress:
        """Return the ``ETHERnet:GATEWay:IPADDress`` command.

        **Description:**
            - This command specifies the network gateway IP address.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:GATEWay:IPADDress?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:GATEWay:IPADDress?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:GATEWay:IPADDress value``
              command.

        **SCPI Syntax:**

        ::

            - ETHERnet:GATEWay:IPADDress <QString>
            - ETHERnet:GATEWay:IPADDress?

        **Info:**
            - ``<QString>`` is a standard IP address value, enclosed in quotes.
        """
        return self._ipaddress


class EthernetEnetAddress(SCPICmdRead):
    """The ``ETHERnet:ENET:ADDress`` command.

    **Description:**
        - Returns the Ethernet address (MAC address) value assigned to the instrument. This is
          assigned at the factory and can not be changed.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:ENET:ADDress?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:ENET:ADDress?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - ETHERnet:ENET:ADDress?
    """


class EthernetEnet(SCPICmdRead):
    """The ``ETHERnet:ENET`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:ENET?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:ENET?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.address``: The ``ETHERnet:ENET:ADDress`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._address = EthernetEnetAddress(device, f"{self._cmd_syntax}:ADDress")

    @property
    def address(self) -> EthernetEnetAddress:
        """Return the ``ETHERnet:ENET:ADDress`` command.

        **Description:**
            - Returns the Ethernet address (MAC address) value assigned to the instrument. This is
              assigned at the factory and can not be changed.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:ENET:ADDress?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:ENET:ADDress?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - ETHERnet:ENET:ADDress?
        """
        return self._address


class EthernetDomainname(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:DOMAINname`` command.

    **Description:**
        - This command specifies the network domain name.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:DOMAINname?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:DOMAINname?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:DOMAINname value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:DOMAINname <Qstring>
        - ETHERnet:DOMAINname?

    **Info:**
        - ``<QString>`` is the network domain name, enclosed in quotes.
    """


class EthernetDnsIpaddress(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:DNS:IPADDress`` command.

    **Description:**
        - This command specifies the network Domain Name Server (DNS) IP address.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:DNS:IPADDress?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:DNS:IPADDress?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:DNS:IPADDress value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:DNS:IPADDress <QString>
        - ETHERnet:DNS:IPADDress?

    **Info:**
        - ``<QString>`` is a standard IP address value, enclosed in quotes.
    """

    _WRAP_ARG_WITH_QUOTES = True


class EthernetDns(SCPICmdRead):
    """The ``ETHERnet:DNS`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:DNS?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:DNS?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.ipaddress``: The ``ETHERnet:DNS:IPADDress`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._ipaddress = EthernetDnsIpaddress(device, f"{self._cmd_syntax}:IPADDress")

    @property
    def ipaddress(self) -> EthernetDnsIpaddress:
        """Return the ``ETHERnet:DNS:IPADDress`` command.

        **Description:**
            - This command specifies the network Domain Name Server (DNS) IP address.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:DNS:IPADDress?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:DNS:IPADDress?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:DNS:IPADDress value``
              command.

        **SCPI Syntax:**

        ::

            - ETHERnet:DNS:IPADDress <QString>
            - ETHERnet:DNS:IPADDress?

        **Info:**
            - ``<QString>`` is a standard IP address value, enclosed in quotes.
        """
        return self._ipaddress


class EthernetDhcpbootp(SCPICmdWrite, SCPICmdRead):
    """The ``ETHERnet:DHCPbootp`` command.

    **Description:**
        - This command sets the network configuration method to DHCP (that is ON) or static IP
          address (that is OFF).

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet:DHCPbootp?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet:DHCPbootp?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ETHERnet:DHCPbootp value`` command.

    **SCPI Syntax:**

    ::

        - ETHERnet:DHCPbootp {ON|OFF}
        - ETHERnet:DHCPbootp?

    **Info:**
        - ``ON`` enables the instrument to search the network for a DHCP server in order to
          automatically assign a dynamic IP address to the instrument.
        - ``OFF`` disables the instrument to search the network for a DHCP server.
    """


#  pylint: disable=too-many-instance-attributes
class Ethernet(SCPICmdRead):
    """The ``ETHERnet`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``ETHERnet?`` query.
        - Using the ``.verify(value)`` method will send the ``ETHERnet?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.dhcpbootp``: The ``ETHERnet:DHCPbootp`` command.
        - ``.dns``: The ``ETHERnet:DNS`` command tree.
        - ``.domainname``: The ``ETHERnet:DOMAINname`` command.
        - ``.enet``: The ``ETHERnet:ENET`` command tree.
        - ``.gateway``: The ``ETHERnet:GATEWay`` command tree.
        - ``.httpport``: The ``ETHERnet:HTTPPort`` command.
        - ``.ipaddress``: The ``ETHERnet:IPADDress`` command.
        - ``.name``: The ``ETHERnet:NAME`` command.
        - ``.password``: The ``ETHERnet:PASSWord`` command.
        - ``.ping``: The ``ETHERnet:PING`` command.
        - ``.subnetmask``: The ``ETHERnet:SUBNETMask`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "ETHERnet") -> None:
        super().__init__(device, cmd_syntax)
        self._dhcpbootp = EthernetDhcpbootp(device, f"{self._cmd_syntax}:DHCPbootp")
        self._dns = EthernetDns(device, f"{self._cmd_syntax}:DNS")
        self._domainname = EthernetDomainname(device, f"{self._cmd_syntax}:DOMAINname")
        self._enet = EthernetEnet(device, f"{self._cmd_syntax}:ENET")
        self._gateway = EthernetGateway(device, f"{self._cmd_syntax}:GATEWay")
        self._httpport = EthernetHttpport(device, f"{self._cmd_syntax}:HTTPPort")
        self._ipaddress = EthernetIpaddress(device, f"{self._cmd_syntax}:IPADDress")
        self._name = EthernetName(device, f"{self._cmd_syntax}:NAME")
        self._password = EthernetPassword(device, f"{self._cmd_syntax}:PASSWord")
        self._ping = EthernetPing(device, f"{self._cmd_syntax}:PING")
        self._subnetmask = EthernetSubnetmask(device, f"{self._cmd_syntax}:SUBNETMask")

    @property
    def dhcpbootp(self) -> EthernetDhcpbootp:
        """Return the ``ETHERnet:DHCPbootp`` command.

        **Description:**
            - This command sets the network configuration method to DHCP (that is ON) or static IP
              address (that is OFF).

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:DHCPbootp?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:DHCPbootp?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:DHCPbootp value`` command.

        **SCPI Syntax:**

        ::

            - ETHERnet:DHCPbootp {ON|OFF}
            - ETHERnet:DHCPbootp?

        **Info:**
            - ``ON`` enables the instrument to search the network for a DHCP server in order to
              automatically assign a dynamic IP address to the instrument.
            - ``OFF`` disables the instrument to search the network for a DHCP server.
        """
        return self._dhcpbootp

    @property
    def dns(self) -> EthernetDns:
        """Return the ``ETHERnet:DNS`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:DNS?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:DNS?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.ipaddress``: The ``ETHERnet:DNS:IPADDress`` command.
        """
        return self._dns

    @property
    def domainname(self) -> EthernetDomainname:
        """Return the ``ETHERnet:DOMAINname`` command.

        **Description:**
            - This command specifies the network domain name.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:DOMAINname?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:DOMAINname?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:DOMAINname value``
              command.

        **SCPI Syntax:**

        ::

            - ETHERnet:DOMAINname <Qstring>
            - ETHERnet:DOMAINname?

        **Info:**
            - ``<QString>`` is the network domain name, enclosed in quotes.
        """
        return self._domainname

    @property
    def enet(self) -> EthernetEnet:
        """Return the ``ETHERnet:ENET`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:ENET?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:ENET?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.address``: The ``ETHERnet:ENET:ADDress`` command.
        """
        return self._enet

    @property
    def gateway(self) -> EthernetGateway:
        """Return the ``ETHERnet:GATEWay`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:GATEWay?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:GATEWay?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.ipaddress``: The ``ETHERnet:GATEWay:IPADDress`` command.
        """
        return self._gateway

    @property
    def httpport(self) -> EthernetHttpport:
        """Return the ``ETHERnet:HTTPPort`` command.

        **Description:**
            - This command specifies the remote interface HTTP port value.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:HTTPPort?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:HTTPPort?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:HTTPPort value`` command.

        **SCPI Syntax:**

        ::

            - ETHERnet:HTTPPort <QString>
            - ETHERnet:HTTPPort?

        **Info:**
            - ``<QString>`` is an integer port number, enclosed in quotes.
        """
        return self._httpport

    @property
    def ipaddress(self) -> EthernetIpaddress:
        """Return the ``ETHERnet:IPADDress`` command.

        **Description:**
            - This command sets the IP address assigned to the instrument.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:IPADDress?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:IPADDress?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:IPADDress value`` command.

        **SCPI Syntax:**

        ::

            - ETHERnet:IPADDress <QString>
            - ETHERnet:IPADDress?

        **Info:**
            - ``<QString>`` is a standard IP address value, enclosed in quotes.
        """
        return self._ipaddress

    @property
    def name(self) -> EthernetName:
        """Return the ``ETHERnet:NAME`` command.

        **Description:**
            - This command sets or queries the instrument Ethernet hostname assigned to the
              instrument.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:NAME?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:NAME?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:NAME value`` command.

        **SCPI Syntax:**

        ::

            - ETHERnet:NAME <QString>
            - ETHERnet:NAME?

        **Info:**
            - ``<QString>`` is the network name assigned to the instrument, enclosed in quotes.
        """
        return self._name

    @property
    def password(self) -> EthernetPassword:
        """Return the ``ETHERnet:PASSWord`` command.

        **Description:**
            - This command specifies the HTTP Ethernet access password. If a password is set, the
              user must enter the password before the user's Web browser can access the
              oscilloscope.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:PASSWord?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:PASSWord?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:PASSWord value`` command.

        **SCPI Syntax:**

        ::

            - ETHERnet:PASSWord <new>
            - ETHERnet:PASSWord?

        **Info:**
            - ``<new>`` is a new password, enclosed in quotes.
        """
        return self._password

    @property
    def ping(self) -> EthernetPing:
        """Return the ``ETHERnet:PING`` command.

        **Description:**
            - Sends a ping packet to the instrument gateway and sets the status accordingly.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``ETHERnet:PING value`` command.

        **SCPI Syntax:**

        ::

            - ETHERnet:PING EXECute

        Sub-properties:
            - ``.status``: The ``ETHERnet:PING:STATUS`` command.
        """
        return self._ping

    @property
    def subnetmask(self) -> EthernetSubnetmask:
        """Return the ``ETHERnet:SUBNETMask`` command.

        **Description:**
            - This command sets or queries the instrument subnet mask value.

        **Usage:**
            - Using the ``.query()`` method will send the ``ETHERnet:SUBNETMask?`` query.
            - Using the ``.verify(value)`` method will send the ``ETHERnet:SUBNETMask?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ETHERnet:SUBNETMask value``
              command.

        **SCPI Syntax:**

        ::

            - ETHERnet:SUBNETMask <QString>
            - ETHERnet:SUBNETMask?

        **Info:**
            - ``<QString>`` is the subnet mask value, enclosed in quotes.
        """
        return self._subnetmask
